@@ -413,8 +413,10 @@ class MeanLine(IndLine):
                         continue
                     else:
                         time_values.append(self.dicts[condition][rep]["Values"][ind])
-                # Finish up by updating the temporary dict with the values, and then the mean dictionary.
-                tmp_dict.update({time: time_values})
+                # Finish up by updating the temporary dict with the values, and then the mean dictionary (but only if
+                # there are values in the time_values, else we'll append an empty list
+                if time_values:
+                    tmp_dict.update({time: time_values})
             self.mean_dict.update({condition: tmp_dict})
         # All that is left now is calculate the means and the associated
         for condition in self.mean_dict.keys():
